searchData={"content_type":"text/markdown","items":[{"doc":"Debugging functions for making life easier.","ref":"ExDebug.html","title":"ExDebug","type":"module"},{"doc":"Prints the `input` argument in console within a formatted frame.\r\n\r\nThe function will always return the `input` argument as a passthrough. the given `input` term will only be printed in the console in **:dev** and **:test** environments, in any other environment (such as **:prod**), there will be no printing.\r\n\r\nIt can recieve a keyword list as options.","ref":"ExDebug.html#console/2","title":"ExDebug.console/2","type":"function"},{"doc":"* `label`: A string to print on the header for identification purposes.\r\n  * `color`: Color of the label if its given. Values between 0-255.\r\n  * `width`: Lenght of characters to be used in the console print.\r\n  * `line_color`: Color of the header and footer lines. Values between 0-255.\r\n  * `time_color`: Color of the execution time. Values between 0-255.\r\n  * `syntax_colors`: Keyword list for term syntax color.\r\n    \r\n    Keys: `:atom`, `:binary`, `:boolean`, `:list`, `:map`, `:nil`, `:number`, `:regex`, `:reset`, `:string`, `:tuple`.\r\n    \r\n    Values: `:black`, `:red`, `:yellow`, `:green`, `:cyan`, `:blue`, `:magenta`, `:white`, `:light_black`, `:light_red`, `:light_yellow`, `:light_green`, `:light_cyan`, `:light_blue`, `:light_magenta`, `:light_white`.","ref":"ExDebug.html#console/2-options","title":"Options - ExDebug.console/2","type":"function"},{"doc":"##  Example\r\n    iex> \"Lorem-Ipsum\"\r\n    ...> |> String.split(\"-\")\r\n    ...> |> ExDebug.console(label: \"Split return\")\r\n    ...> |> Enum.join()\r\n    ...> |> String.downcase()\r\n    # Split return -------------------------------------- 2022-03-10 - 00:47:07.523741\r\n    # [\"Lorem\", \"Ipsum\"]\r\n    # ------------------------------------------------------------------- MyApp v0.0.0\r\n    \"loremipsum\" # <- This is the actual pipeline return, besides de console print.","ref":"ExDebug.html#console/2-256-color-palette","title":"256 color palette - ExDebug.console/2","type":"function"},{"doc":"<!-- markdownlint-disable MD033 -->\r\n# ExDebug\r\n\r\n![version - 1.0.0](https://img.shields.io/badge/version-1.0.0-white.svg?style=flat-sector&color=lightgray)\r\n\r\nElixir library with debugging functions for making life easier.","ref":"readme.html","title":"Getting Started","type":"extras"},{"doc":"The package can be installed\r\nby adding `ex_debug` to your list of dependencies in `mix.exs`:\r\n\r\n```elixir\r\ndef deps do\r\n  [\r\n    {:ex_debug, \"~> 1.0.0\"}\r\n  ]\r\nend\r\n```\r\n\r\nDocumentation generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\r\nand published on [HexDocs](https://hexdocs.pm).\r\nThe docs can be found at:  .","ref":"readme.html#installation","title":"Installation - Getting Started","type":"extras"},{"doc":"When using the `ExDebug.console\\2` function, it's possible to pass some formatting options to the function. There is a configuration in `config/config.exs` file that can be adjusted to set these options globally:\r\n\r\n```elixir\r\n# config/config.exs file\r\n\r\nconfig :ex_debug,\r\n  width: 80,\r\n  color: 255,\r\n  line_color: 238,\r\n  time_color: 247,\r\n  syntax_colors: [\r\n    atom:    :cyan,\r\n    binary:  :white,\r\n    boolean: :magenta,\r\n    list:    :white,\r\n    map:     :white,\r\n    nil:     :magenta,\r\n    number:  :yellow,\r\n    regex:   :light_red,\r\n    reset:   :yellow,\r\n    string:  :green,\r\n    tuple:   :white\r\n  ]\r\n```","ref":"readme.html#configuration","title":"Configuration - Getting Started","type":"extras"},{"doc":"- **width**: Lenght of characters to be used in the console print.\r\n- **color**: Color of the label if its given. Values between 0-255.\r\n- **line_color**: Color of the header and footer lines. Values between 0-255.\r\n- **time_color**: Color of the execution time. Values between 0-255.\r\n- **syntax_colors**: Keyword list for term syntax color.\r\n\r\n    **Keys**: `:atom`, `:binary`, `:boolean`, `:list`, `:map`, `:nil`, `:number`, `:regex`, `:reset`, `:string`, `:tuple`.\r\n\r\n    **Values**: `:black`, `:red`, `:yellow`, `:green`, `:cyan`, `:blue`, `:magenta`, `:white`, `:light_black`, `:light_red`, `:light_yellow`, `:light_green`, `:light_cyan`, `:light_blue`, `:light_magenta`, `:light_white`.","ref":"readme.html#configuration-parameters","title":"Configuration parameters - Getting Started","type":"extras"},{"doc":"","ref":"readme.html#256-color-palette","title":"256 color palette - Getting Started","type":"extras"},{"doc":"","ref":"readme.html#use","title":"Use - Getting Started","type":"extras"},{"doc":"Use the `ExDebug.console\\2` function chaining it anywhere in your functions pipelines, to print in console the current data on that point of the pipeline.\r\n\r\nThis behavior is only present in the `:dev` and `:test` environments. If it's called in the `:prod` (or any other) environment, it will simply ignore the command and pass through the data.\r\n\r\n#### Example\r\n\r\n```elixir\r\niex> \"Lorem-Ipsum\"\r\n...> |> String.split(\"-\")\r\n...> |> ExDebug.console(label: \"Split return\")\r\n...> |> Enum.join()\r\n...> |> String.downcase()\r\n# Split return -------------------------------------- 2022-03-10 - 00:47:07.523741\r\n# [\"Lorem\", \"Ipsum\"]\r\n# ------------------------------------------------------------------- MyApp v0.0.0\r\n\"loremipsum\" # <- This is the actual pipeline return, besides de console print.\r\n```","ref":"readme.html#exdebug-console","title":"ExDebug.console - Getting Started","type":"extras"},{"doc":"<!-- markdownlint-disable MD024 -->\r\n# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"","ref":"changelog.html#v1-0-0-2021-04-17","title":"v1.0.0 (2021-04-17) - Changelog","type":"extras"},{"doc":"- Project name changed from `Debug` to `ExDebug` due previous library in existance in hexdocs.","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"","ref":"changelog.html#v0-2-0-2021-04-17","title":"v0.2.0 (2021-04-17) - Changelog","type":"extras"},{"doc":"- Configuration options through `config/config.ex` file instead compilation-time variables inside de module.","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"","ref":"changelog.html#v0-1-0-2024-04-09","title":"v0.1.0 (2024-04-09) - Changelog","type":"extras"},{"doc":"- The `Debug.console\\2` function prints any term into the console only in `:test` and `:dev` environments. It ignores any other environment and simply passes through the data.","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}